Program SysVars;

{ a small test of pointing  the return from mt_inf at the system variables. }

Uses
  qdos;

Const
  { How wide to print the syste variable names }
  width = 35;

  { System Identifier constants }
  sysid_ql = $D2540000;    { QL (QDOS) system variable identifier }
  sysid_at = $53324154;    { SMS Atari system variable identifier }
  sysid_sq = $534D5351;    { SMSQ identifier }
  sysid_th = $DC010000;    { Thor (ARGOS) system variable identifier }

  { Display Type constants }
  dtype_monitor = 0;
  dtype_tv_625 = 1;
  dtype_tv_525 = 2;

  { Machine Identifier constants }
  mtype_st = 0;
  mtype_mega_st_rtc = 2;
  mtype_stacy = 4;
  mtype_ste = 6;
  mtype_mega_ste = 8;
  mtype_gold_card = $0A;
  mtype_super_gold_card = $0C;
  mtype_falcon = $10;
  mtype_q40_q60 = $11;
  mtype_smsqmulator = $14;
  mtype_tt = $18;
  mtype_qxl = $1C;
  mtype_qpc = $1E;

Type
  Tver = array[0..3] of char;
  {$i sysvars.inc}

Var
  job_id: longint;
  aPointer: longint;
  ver_ascii: longint;
  system_vars: pSystemVariables;
  x, y: integer;

{ Procedure to pause for the next page of details. }
Function pause: boolean;
Var
  Enter: char;
begin
  Pause := true;
  Writeln;
  while (true) do
  begin
    Write('"C" to Continue, "Q" to Quit....');
    Flush(output);
    readln(Enter);
    if Enter in ['C','c'] then 
       exit;
    if Enter in ['Q','q'] then
    begin
      Pause := false;
      exit;
    end;
  end;
end;

  
begin
  job_id:=mt_inf(@system_vars,@ver_ascii);

  writeln('Version: $':width,hexstr(ver_ascii,8),' (',Tver(ver_ascii), ')');
  writeln('System vars at: $':width,hexstr(system_vars));
  write('Identification: $':width,hexstr(system_vars^.SYS_IDNT,8), ' (');
  case system_vars^.SYS_IDNT of
     SYSID_QL: writeln('QDOS)');
     SYSID_SQ: writeln('SMSQ)');
     SYSID_AT: writeln('Atari)');
     SYSID_TH: writeln('Thor)');
  else
     writeln('Unknown)');
  end;

  writeln('Common Heap Start: $':width,hexstr(system_vars^.SYS_CHPB));
  writeln('Common Heap Free: $':width,hexstr(system_vars^.SYS_CHPF));
  writeln('Free Area Start: $':width,hexstr(system_vars^.SYS_FSBB));
  writeln('SuperBASIC Start: $':width,hexstr(system_vars^.SYS_SBAB));
  writeln('Transient Area Start: $':width,hexstr(system_vars^.SYS_TPAB));
  writeln('Transient Area Start: $':width,hexstr(system_vars^.SYS_TPAF));
  writeln('Resident Procs Area Start: $':width,hexstr(system_vars^.SYS_RPAB));
  writeln('End of RAM + 1: $':width,hexstr(system_vars^.SYS_RAMT));
  writeln('Max Free Memory call: $':width,hexstr(system_vars^.SYS_MXFR));
  writeln('Real Time (Seconds): $':width,hexstr(system_vars^.SYS_RTC, 8));
  writeln('Real Time (Seconds): $':width,hexstr(system_vars^.SYS_RTCF, 4));
  writeln('Random number:  ':width,system_vars^.SYS_RAND);
  writeln('Missed Polling Interrupts:  ':width,system_vars^.SYS_PICT);
  write('Display Type:  ':width, system_vars^.SYS_DTYP, '( ');
  case system_vars^.SYS_DTYP of
    DTYPE_MONITOR: writeln('Monitor)');
    DTYPE_TV_625: writeln('TV (PAL))');
    DTYPE_TV_525: writeln('TV (NSTC))');
  else
     { QDOS, PAL TV }
     writeln('TV (PAL)'); 
  end;

  writeln('Display Frozen:  ':width, system_vars^.SYS_DFRZ);
  writeln('Master Chip Register value:  ':width, system_vars^.SYS_QLMR);
  writeln('Interrupt Register value:  ':width, system_vars^.SYS_QLIR);
  writeln('OK to reschedule:  ':width, system_vars^.SYS_RSHD);
  writeln('Network Number:  ':width, system_vars^.SYS_NNNR);
  writeln('Ext Interrupt action list: $':width,hexstr(system_vars^.SYS_EXIL));

  if not pause then 
    exit;

  writeln('Polled action list: $':width,hexstr(system_vars^.SYS_POLL));
  writeln('Scheduler Loop action list: $':width,hexstr(system_vars^.SYS_SHDL));
  writeln('Filing System Driver list: $':width,hexstr(system_vars^.SYS_FSDL));
  writeln('Current Keyboard Queue: $':width,hexstr(system_vars^.SYS_CKYQ));
  writeln('Exception Redirection Table: $':width,hexstr(system_vars^.SYS_ERTB));
  writeln('Slave Block Running Pointer: $':width,hexstr(system_vars^.SYS_SBRP));
  writeln('Slave Block Table Base: $':width,hexstr(system_vars^.SYS_SBTB));
  writeln('Slave Block Table Top: $':width,hexstr(system_vars^.SYS_SBTT));
  writeln('Next Job Tag:  ':width, system_vars^.SYS_JBTG);
  writeln('Highest Job in Table:  ':width, system_vars^.SYS_JBTP);
  writeln('Current Job  Pointer: $':width,hexstr(system_vars^.SYS_JBPT));
  writeln('Job Table Base: $':width,hexstr(system_vars^.SYS_JBTB));
  writeln('Job Table Top: $':width,hexstr(system_vars^.SYS_JBTT));
  writeln('Next Channel Tag:  ':width, system_vars^.SYS_CHTG);
  writeln('Highest Channel in Table:  ':width, system_vars^.SYS_CHTP);
  writeln('Last Checked Channel Pointer: $':width,hexstr(system_vars^.SYS_CHPT));
  writeln('Channel Table Base: $':width,hexstr(system_vars^.SYS_CHTB));
  writeln('Channel Table Top: $':width,hexstr(system_vars^.SYS_CHTT));
  writeln('Free Block List (returnable): $':width,hexstr(system_vars^.SYS_FRBL));
  writeln('Thor Flag:  ':width, system_vars^.SYS_TSDD);
  write('Caps Lock Flag: $':width, hexstr(system_vars^.SYS_CAPS, 4), ' (CAPS ');
  case system_vars^.SYS_CAPS of
    0: writeln('OFF)');
  else
    writeln('ON)');
  end;
  writeln('Repeat Character:  ':width, system_vars^.SYS_LCHR);
  writeln('Repeat Delay (20ms units) :  ':width, system_vars^.SYS_RDEL);

  if not pause then 
    exit;

  writeln('Repeat Time (20ms units) :  ':width, system_vars^.SYS_RTIM);
  writeln('Repeat Counter :  ':width, system_vars^.SYS_RCNT);
  writeln('Switch K/B Queue Character:  ':width, system_vars^.SYS_SWTC);
  writeln('Beeping?:  ':width, system_vars^.SYS_QLBP);
  writeln('Receive Channel (SER1): $':width,hexstr(system_vars^.SYS_SER1));
  writeln('Receive Channel (SER2): $':width,hexstr(system_vars^.SYS_SER2));
  writeln('ZX8302 Transmit Mode:  ':width, system_vars^.SYS_TMOD);
  writeln('Processor Type:  ':width, '680', hexstr(system_vars^.SYS_PTYP,2));
  writeln('Caps Lock subroutine:  ':width, hexstr(system_vars^.SYS_CSUB));
  writeln('DMA in use?:  ':width, system_vars^.SYS_DMIU);
  writeln('Machine Type:  ':width, system_vars^.SYS_MTYP);
  writeln('Polling Frequency:  ':width, system_vars^.SYS_POLF);
  writeln('Flashing Cursor Status:  ':width, system_vars^.SYS_CFST);

  { The next 4 pointers are to a QDOS String (word.bytes) which would be
    nice to decode! }
  writeln('Program Default: $':width,hexstr(system_vars^.SYS_PRGD));    // FIXME!
  writeln('Data Default: $':width,hexstr(system_vars^.SYS_DATD));       // FIXME!
  writeln('Dest Default: $':width,hexstr(system_vars^.SYS_DSTD));       // FIXME!
  writeln('Thing List: $':width,hexstr(system_vars^.SYS_THGL));         // FIXME!

  writeln('Primary Stack Frame: $':width,hexstr(system_vars^.SYS_PSF));

  writeln('200 Hz in service:  ':width, system_vars^.SYS_200I);
  writeln('50 Hz in service:  ':width, system_vars^.SYS_50I);
  writeln('10 Hz in service:  ':width, system_vars^.SYS_10I);
  writeln('Poll Requested:  ':width, system_vars^.SYS_PLRQ);
  writeln('Console Linkage: $':width,hexstr(system_vars^.SYS_CLNK));

  if not pause then 
    exit;

  writeln('Instruction Cache:  ':width, system_vars^.SYS_CASTAT);
  writeln('Cache Suppressed Timer:  ':width, system_vars^.SYS_CASUP);
  writeln('I/O Priority:  ':width, system_vars^.SYS_IOPR);
  writeln('Current SBASIC: $':width,hexstr(system_vars^.SYS_CBAS));

  write('Floating Point Unit: ':width - 1);
  { Just write the FPU stuff as 4 long words. }
  for x := 0 to 3 do
  begin
    write('$');
    for y := 0 to 3 do
      write(hexstr(system_vars^.SYS_FPU[x * 4 + y],2));
    write(' ');
  end;
  writeln;

  writeln('Real Time Clock Protected:  ':width, system_vars^.SYS_PRTC);
  writeln('Memory Protection Level:  ':width, system_vars^.SYS_PMEM);
  writeln('Slug Level:  ':width, system_vars^.SYS_SLUG);
  writeln('Key Lock:  ':width, system_vars^.SYS_KLOCK);
  writeln('Mini Tick Counter:  ':width, system_vars^.SYS_MTICK);
  writeln('Keyboard Linkage: $':width, hexstr(system_vars^.SYS_KLNK));
  writeln('Running Microdrive Number:  ':width, system_vars^.SYS_MDRN);
  writeln('Microdrive Run-up/down Counter:  ':width, system_vars^.SYS_MDCT);
  write('Microdrive Drive ID (*4):  ':width);
  for x := low(system_vars^.SYS_MDID) to high(system_vars^.SYS_MDID) do
    write(system_vars^.SYS_MDID[x], ' ');
  writeln;

  write('Microdrive Drive Status:  ':width);
  for x := low(system_vars^.SYS_MDST) to high(system_vars^.SYS_MDST) do
    write(system_vars^.SYS_MDST[x], ' ');
  writeln;

  write('Filing System Drive Definitions: ':width - 1);
  for x := 0 to 3 do
  begin  
    if x > 0 then
      write(' ':width - 1);
    for y := 0 to 3 do
       write('$', hexstr(system_vars^.SYS_FSDD[x * 4 + y]), ' ');
    writeln;
  end;

  writeln('System Channels Linked List: $':width, hexstr(system_vars^.SYS_FSCH));
  writeln('TRANSLATE Active?:  ':width, system_vars^.SYS_XACT);
  writeln('TRANSLATE Table: $':width, hexstr(system_vars^.SYS_XTAB));
  writeln('Error Message Table: $':width, hexstr(system_vars^.SYS_ERMS));
  writeln('Messages Table: $':width, hexstr(system_vars^.SYS_MSTAB));


  if not pause then 
    exit;

  writeln('Used by TURBO: $':width, hexstr(system_vars^.SYS_TURBO, 8));
  writeln('Used by QSOUND: $':width, hexstr(system_vars^.SYS_QSOUND, 8));
  writeln('Language Module List: $':width, hexstr(system_vars^.SYS_LDMLST));
  writeln('Current Language: $':width, hexstr(system_vars^.SYS_LANG, 4));
  writeln('Operating System Version: $':width, hexstr(system_vars^.SYS_VERS, 8));
  writeln('Use RECENT Thing?:  ':width, system_vars^.SYS_RTHG);
  writeln('Suspend Delay After EXECing Job:  ':width, system_vars^.SYS_XDLY);
  writeln('OUCH!:  ':width, system_vars^.SYS_OUCH);





  writeln;
end.



